const Wait = require('./wait');

function waitElementVisible(page, elementSelector) {
  const wait = new Wait(page, elementSelector);
  wait.waitElementVisible();
}

const ExpectElement = require('./expect');

class RadioButton {
  constructor(page, elementSelector, value) {
    this.page = page;
    this.elementSelector = elementSelector;
    this.value = value;
    this.valueIndexSelector = `${this.elementSelector}>input[value='${this.value}']`;
  }

  isRadioButton() {
    return this.page.expect.element(this.elementSelector).to.be.a('input');
  }

  selectRadioButtonByValue() {
    // this.isRadioButton();
    waitElementVisible(this.page, this.elementSelector);
    return this.page.click(this.elementSelector, () => {
      if (this.value === '' || this.value === undefined) {
        this.page.click(`${this.elementSelector}>input[value]`);
      } else {
        this.page.click(this.valueIndexSelector);
      }
    });
  }

  selectRadioButton() {
    // this.isRadioButton();
    waitElementVisible(this.page, this.elementSelector);
    this.page.click(this.elementSelector);
  }

  expectRadioButtonSelected() {
    const expectElement = new ExpectElement(this.page, this.elementSelector);
    expectElement.expectElementSelected();
  }

  expectRadioButtonSelectedValue() {
    this.page.getValue(this.elementSelector, (result) => {
      this.page.assert.equal(result.value, this.value);
      this.expectRadioButtonSelected();
    });
  }
}

module.exports = RadioButton;
